var NAVTREEINDEX11 =
{
"interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[27,0,0,31],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[27,0,0,32],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[26,0,0,32],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__model.html":[27,0,0,33],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__model.html":[26,0,0,33],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html":[27,0,0,34],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html":[26,0,0,34],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__nbuffers.html":[27,0,0,35],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__nbuffers.html":[26,0,0,35],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__type.html":[27,0,0,36],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__type.html":[26,0,0,36],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__variable__nbuffers.html":[27,0,0,37],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__variable__nbuffers.html":[26,0,0,37],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__where.html":[27,0,0,38],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__where.html":[26,0,0,38],
"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__count.html":[27,0,0,39],
"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__count.html":[26,0,0,39],
"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__id.html":[27,0,0,40],
"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__id.html":[26,0,0,40],
"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__rank.html":[27,0,0,41],
"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__rank.html":[26,0,0,41],
"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__size.html":[27,0,0,42],
"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__size.html":[26,0,0,42],
"interfacefstarpu__mod_1_1fstarpu__conf__allocate.html":[27,0,0,43],
"interfacefstarpu__mod_1_1fstarpu__conf__allocate.html":[26,0,0,43],
"interfacefstarpu__mod_1_1fstarpu__conf__free.html":[26,0,0,44],
"interfacefstarpu__mod_1_1fstarpu__conf__free.html":[27,0,0,44],
"interfacefstarpu__mod_1_1fstarpu__conf__init.html":[26,0,0,45],
"interfacefstarpu__mod_1_1fstarpu__conf__init.html":[27,0,0,45],
"interfacefstarpu__mod_1_1fstarpu__conf__set__max__prio.html":[26,0,0,46],
"interfacefstarpu__mod_1_1fstarpu__conf__set__max__prio.html":[27,0,0,46],
"interfacefstarpu__mod_1_1fstarpu__conf__set__min__prio.html":[26,0,0,47],
"interfacefstarpu__mod_1_1fstarpu__conf__set__min__prio.html":[27,0,0,47],
"interfacefstarpu__mod_1_1fstarpu__conf__set__ncpu.html":[26,0,0,48],
"interfacefstarpu__mod_1_1fstarpu__conf__set__ncpu.html":[27,0,0,48],
"interfacefstarpu__mod_1_1fstarpu__conf__set__ncuda.html":[26,0,0,49],
"interfacefstarpu__mod_1_1fstarpu__conf__set__ncuda.html":[27,0,0,49],
"interfacefstarpu__mod_1_1fstarpu__conf__set__nopencl.html":[27,0,0,50],
"interfacefstarpu__mod_1_1fstarpu__conf__set__nopencl.html":[26,0,0,50],
"interfacefstarpu__mod_1_1fstarpu__conf__set__sched__policy__name.html":[26,0,0,51],
"interfacefstarpu__mod_1_1fstarpu__conf__set__sched__policy__name.html":[27,0,0,51],
"interfacefstarpu__mod_1_1fstarpu__cpu__worker__get__count.html":[27,0,0,52],
"interfacefstarpu__mod_1_1fstarpu__cpu__worker__get__count.html":[26,0,0,52],
"interfacefstarpu__mod_1_1fstarpu__create__sync__task.html":[26,0,0,53],
"interfacefstarpu__mod_1_1fstarpu__create__sync__task.html":[27,0,0,53],
"interfacefstarpu__mod_1_1fstarpu__cublas__init.html":[26,0,0,54],
"interfacefstarpu__mod_1_1fstarpu__cublas__init.html":[27,0,0,54],
"interfacefstarpu__mod_1_1fstarpu__cublas__shutdown.html":[27,0,0,55],
"interfacefstarpu__mod_1_1fstarpu__cublas__shutdown.html":[26,0,0,55],
"interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html":[27,0,0,56],
"interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html":[26,0,0,56],
"interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[27,0,0,57],
"interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[26,0,0,57],
"interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[26,0,0,58],
"interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[27,0,0,58],
"interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[26,0,0,59],
"interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[27,0,0,59],
"interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[26,0,0,60],
"interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[27,0,0,60],
"interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[27,0,0,61],
"interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[26,0,0,61],
"interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[26,0,0,62],
"interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[27,0,0,62],
"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[27,0,0,63],
"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[26,0,0,63],
"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[27,0,0,64],
"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[26,0,0,64],
"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[27,0,0,65],
"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[26,0,0,65],
"interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[27,0,0,66],
"interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[26,0,0,66],
"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[27,0,0,67],
"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[26,0,0,67],
"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[27,0,0,68],
"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[26,0,0,68],
"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[27,0,0,69],
"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[26,0,0,69],
"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[26,0,0,70],
"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[27,0,0,70],
"interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[27,0,0,71],
"interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[26,0,0,71],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[27,0,0,72],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[26,0,0,72],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[27,0,0,73],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[26,0,0,73],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[27,0,0,74],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[26,0,0,74],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[27,0,0,75],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[26,0,0,75],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[27,0,0,76],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[26,0,0,76],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[27,0,0,77],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[26,0,0,77],
"interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[27,0,0,78],
"interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[26,0,0,78],
"interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[26,0,0,79],
"interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[27,0,0,79],
"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[27,0,0,80],
"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[26,0,0,80],
"interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[27,0,0,81],
"interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[26,0,0,81],
"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[26,0,0,82],
"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[27,0,0,82],
"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[26,0,0,83],
"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[27,0,0,83],
"interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[27,0,0,84],
"interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[26,0,0,84],
"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[27,0,0,85],
"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[26,0,0,85],
"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[27,0,0,86],
"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[26,0,0,86],
"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[27,0,0,87],
"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[26,0,0,87],
"interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[27,0,0,88],
"interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[26,0,0,88],
"interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[27,0,0,89],
"interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[26,0,0,89],
"interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[27,0,0,90],
"interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[26,0,0,90],
"interfacefstarpu__mod_1_1fstarpu__data__map__filters.html":[26,0,0,91],
"interfacefstarpu__mod_1_1fstarpu__data__map__filters.html":[27,0,0,91],
"interfacefstarpu__mod_1_1fstarpu__data__partition.html":[27,0,0,92],
"interfacefstarpu__mod_1_1fstarpu__data__partition.html":[26,0,0,92],
"interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[27,0,0,93],
"interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[26,0,0,93],
"interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[27,0,0,94],
"interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[26,0,0,94],
"interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[27,0,0,95],
"interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[26,0,0,95],
"interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[27,0,0,96],
"interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[26,0,0,96],
"interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[27,0,0,97],
"interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[26,0,0,97],
"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[27,0,0,98],
"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[26,0,0,98],
"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[27,0,0,99],
"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[26,0,0,99],
"interfacefstarpu__mod_1_1fstarpu__data__register__same.html":[26,0,0,100],
"interfacefstarpu__mod_1_1fstarpu__data__register__same.html":[27,0,0,100],
"interfacefstarpu__mod_1_1fstarpu__data__release.html":[27,0,0,101],
"interfacefstarpu__mod_1_1fstarpu__data__release.html":[26,0,0,101],
"interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html":[26,0,0,102],
"interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html":[27,0,0,102],
"interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html":[26,0,0,103],
"interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html":[27,0,0,103],
"interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods.html":[27,0,0,104],
"interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods.html":[26,0,0,104],
"interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods__with__args.html":[26,0,0,105],
"interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods__with__args.html":[27,0,0,105],
"interfacefstarpu__mod_1_1fstarpu__data__test__if__allocated__on__node.html":[27,0,0,106],
"interfacefstarpu__mod_1_1fstarpu__data__test__if__allocated__on__node.html":[26,0,0,106],
"interfacefstarpu__mod_1_1fstarpu__data__unpartition.html":[27,0,0,107],
"interfacefstarpu__mod_1_1fstarpu__data__unpartition.html":[26,0,0,107],
"interfacefstarpu__mod_1_1fstarpu__data__unpartition__readonly__submit.html":[27,0,0,108],
"interfacefstarpu__mod_1_1fstarpu__data__unpartition__readonly__submit.html":[26,0,0,108],
"interfacefstarpu__mod_1_1fstarpu__data__unpartition__submit.html":[27,0,0,109],
"interfacefstarpu__mod_1_1fstarpu__data__unpartition__submit.html":[26,0,0,109],
"interfacefstarpu__mod_1_1fstarpu__data__unregister.html":[27,0,0,110],
"interfacefstarpu__mod_1_1fstarpu__data__unregister.html":[26,0,0,110],
"interfacefstarpu__mod_1_1fstarpu__data__unregister__no__coherency.html":[26,0,0,111],
"interfacefstarpu__mod_1_1fstarpu__data__unregister__no__coherency.html":[27,0,0,111],
"interfacefstarpu__mod_1_1fstarpu__data__unregister__submit.html":[26,0,0,112],
"interfacefstarpu__mod_1_1fstarpu__data__unregister__submit.html":[27,0,0,112],
"interfacefstarpu__mod_1_1fstarpu__data__wont__use.html":[26,0,0,113],
"interfacefstarpu__mod_1_1fstarpu__data__wont__use.html":[27,0,0,113],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__bcsr__filter__canonical__block.html":[27,0,0,114],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__bcsr__filter__canonical__block.html":[26,0,0,114],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block.html":[26,0,0,115],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block.html":[27,0,0,115],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block__shadow.html":[27,0,0,116],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block__shadow.html":[26,0,0,116],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__vertical__block.html":[27,0,0,117],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__vertical__block.html":[26,0,0,117],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__vertical__block__shadow.html":[27,0,0,118],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__vertical__block__shadow.html":[26,0,0,118],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__csr__filter__vertical__block.html":[27,0,0,119],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__csr__filter__vertical__block.html":[26,0,0,119],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__block.html":[27,0,0,120],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__block.html":[26,0,0,120],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__block__shadow.html":[26,0,0,121],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__block__shadow.html":[27,0,0,121],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block.html":[27,0,0,122],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block.html":[26,0,0,122],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block__shadow.html":[27,0,0,123],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block__shadow.html":[26,0,0,123],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__block.html":[26,0,0,124],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__block.html":[27,0,0,124],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__block__shadow.html":[26,0,0,125],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__block__shadow.html":[27,0,0,125],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__divide__in__2.html":[26,0,0,126],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__divide__in__2.html":[27,0,0,126],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__list.html":[26,0,0,127],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__list.html":[27,0,0,127],
"interfacefstarpu__mod_1_1fstarpu__display__memory__stats.html":[26,0,0,128],
"interfacefstarpu__mod_1_1fstarpu__display__memory__stats.html":[27,0,0,128],
"interfacefstarpu__mod_1_1fstarpu__display__stats.html":[26,0,0,129],
"interfacefstarpu__mod_1_1fstarpu__display__stats.html":[27,0,0,129],
"interfacefstarpu__mod_1_1fstarpu__do__schedule.html":[26,0,0,130],
"interfacefstarpu__mod_1_1fstarpu__do__schedule.html":[27,0,0,130],
"interfacefstarpu__mod_1_1fstarpu__free__noflag.html":[26,0,0,131],
"interfacefstarpu__mod_1_1fstarpu__free__noflag.html":[27,0,0,131],
"interfacefstarpu__mod_1_1fstarpu__free__on__node.html":[26,0,0,132],
"interfacefstarpu__mod_1_1fstarpu__free__on__node.html":[27,0,0,132],
"interfacefstarpu__mod_1_1fstarpu__fxt__autostart__profiling.html":[26,0,0,133],
"interfacefstarpu__mod_1_1fstarpu__fxt__autostart__profiling.html":[27,0,0,133],
"interfacefstarpu__mod_1_1fstarpu__fxt__generate__trace.html":[26,0,0,134],
"interfacefstarpu__mod_1_1fstarpu__fxt__generate__trace.html":[27,0,0,134],
"interfacefstarpu__mod_1_1fstarpu__fxt__options__init.html":[27,0,0,135],
"interfacefstarpu__mod_1_1fstarpu__fxt__options__init.html":[26,0,0,135],
"interfacefstarpu__mod_1_1fstarpu__fxt__start__profiling.html":[26,0,0,136],
"interfacefstarpu__mod_1_1fstarpu__fxt__start__profiling.html":[27,0,0,136],
"interfacefstarpu__mod_1_1fstarpu__fxt__stop__profiling.html":[26,0,0,137],
"interfacefstarpu__mod_1_1fstarpu__fxt__stop__profiling.html":[27,0,0,137],
"interfacefstarpu__mod_1_1fstarpu__fxt__write__data__trace.html":[26,0,0,138],
"interfacefstarpu__mod_1_1fstarpu__fxt__write__data__trace.html":[27,0,0,138],
"interfacefstarpu__mod_1_1fstarpu__get__version.html":[26,0,0,139],
"interfacefstarpu__mod_1_1fstarpu__get__version.html":[27,0,0,139],
"interfacefstarpu__mod_1_1fstarpu__insert__task.html":[26,0,0,140],
"interfacefstarpu__mod_1_1fstarpu__insert__task.html":[27,0,0,140],
"interfacefstarpu__mod_1_1fstarpu__is__paused.html":[26,0,0,141],
"interfacefstarpu__mod_1_1fstarpu__is__paused.html":[27,0,0,141],
"interfacefstarpu__mod_1_1fstarpu__malloc.html":[26,0,0,142],
"interfacefstarpu__mod_1_1fstarpu__malloc.html":[27,0,0,142],
"interfacefstarpu__mod_1_1fstarpu__malloc__on__node.html":[26,0,0,143],
"interfacefstarpu__mod_1_1fstarpu__malloc__on__node.html":[27,0,0,143],
"interfacefstarpu__mod_1_1fstarpu__matrix__data__register.html":[27,0,0,144],
"interfacefstarpu__mod_1_1fstarpu__matrix__data__register.html":[26,0,0,144],
"interfacefstarpu__mod_1_1fstarpu__matrix__filter__block.html":[26,0,0,145],
"interfacefstarpu__mod_1_1fstarpu__matrix__filter__block.html":[27,0,0,145],
"interfacefstarpu__mod_1_1fstarpu__matrix__filter__block__shadow.html":[27,0,0,146],
"interfacefstarpu__mod_1_1fstarpu__matrix__filter__block__shadow.html":[26,0,0,146],
"interfacefstarpu__mod_1_1fstarpu__matrix__filter__vertical__block.html":[27,0,0,147],
"interfacefstarpu__mod_1_1fstarpu__matrix__filter__vertical__block.html":[26,0,0,147],
"interfacefstarpu__mod_1_1fstarpu__matrix__filter__vertical__block__shadow.html":[27,0,0,148],
"interfacefstarpu__mod_1_1fstarpu__matrix__filter__vertical__block__shadow.html":[26,0,0,148],
"interfacefstarpu__mod_1_1fstarpu__matrix__get__ld.html":[27,0,0,149],
"interfacefstarpu__mod_1_1fstarpu__matrix__get__ld.html":[26,0,0,149],
"interfacefstarpu__mod_1_1fstarpu__matrix__get__nx.html":[27,0,0,150],
"interfacefstarpu__mod_1_1fstarpu__matrix__get__nx.html":[26,0,0,150],
"interfacefstarpu__mod_1_1fstarpu__matrix__get__ny.html":[27,0,0,151],
"interfacefstarpu__mod_1_1fstarpu__matrix__get__ny.html":[26,0,0,151],
"interfacefstarpu__mod_1_1fstarpu__matrix__get__ptr.html":[27,0,0,152],
"interfacefstarpu__mod_1_1fstarpu__matrix__get__ptr.html":[26,0,0,152],
"interfacefstarpu__mod_1_1fstarpu__matrix__ptr__register.html":[27,0,0,153],
"interfacefstarpu__mod_1_1fstarpu__matrix__ptr__register.html":[26,0,0,153],
"interfacefstarpu__mod_1_1fstarpu__memchunk__tidy.html":[27,0,0,154],
"interfacefstarpu__mod_1_1fstarpu__memchunk__tidy.html":[26,0,0,154],
"interfacefstarpu__mod_1_1fstarpu__memory__nodes__get__count.html":[27,0,0,155],
"interfacefstarpu__mod_1_1fstarpu__memory__nodes__get__count.html":[26,0,0,155],
"interfacefstarpu__mod_1_1fstarpu__memory__pin.html":[27,0,0,156]
};
